#
# spec file for package ibus-chewing
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ibus-chewing
Version:        1.4.14
Release:        3.3
Summary:        The Chewing engine for IBus input platform
License:        GPL-2.0+
Group:          System/I18n/Chinese
Url:            https://github.com/definite/ibus-chewing
Source:         https://github.com/definite/ibus-chewing/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        https://fedorahosted.org/releases/c/m/cmake-fedora/cmake-fedora-modules-only-latest.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  gob2
BuildRequires:  gtk2-devel
BuildRequires:  ibus-devel >= 1.3
BuildRequires:  libchewing-devel >= 0.3.3
BuildRequires:  pkg-config
BuildRequires:  xorg-x11-devel
Requires:       ibus >= 1.3
Provides:       locale(zh_TW)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%glib2_gsettings_schema_requires 

%description
IBus-chewing is an IBus front-end of Chewing, an intelligent Chinese input
method for Zhuyin (BoPoMoFo) users.
It supports various Zhuyin keyboard layout, such as standard (DaChen),
IBM, Gin-Yeah, Eten, Eten 26, Hsu, Dvorak, Dvorak-Hsu, and DaChen26.

Chewing also support toned Hanyu pinyin input.

%prep
%setup -q
tar -xzvf %{_sourcedir}/cmake-fedora-modules-only-latest.tar.gz -C .

%build
%cmake -DLIBEXEC_DIR=%{_libdir}/ibus
make %{?_smp_mflags}

%install
%cmake_install
rm -rf %{buildroot}%{_datadir}/doc/%{name}

# make translations doesn't work
pushd po
for i in *.po ; do
	mkdir -p %{buildroot}%{_datadir}/locale/`echo $i | sed 's/\.po//'`/LC_MESSAGES/
	msgfmt ${i} -o %{buildroot}%{_datadir}/locale/`echo $i | sed 's/\.po//'`/LC_MESSAGES/%{name}.mo
done
popd

%find_lang %{name}

%post
/sbin/ldconfig
%glib2_gsettings_schema_post

%postun
/sbin/ldconfig
%glib2_gsettings_schema_postun

%files -f %{name}.lang
%defattr(-,root,root)
%doc AUTHORS README ChangeLog COPYING
%{_libdir}/ibus/ibus-engine-chewing
%{_libdir}/ibus/ibus-setup-chewing
%{_datadir}/applications/ibus-setup-chewing.desktop
%{_datadir}/glib-2.0/schemas/org.freedesktop.IBus.Chewing.gschema.xml
%{_datadir}/ibus-chewing
%{_datadir}/ibus/component/chewing.xml

%changelog
* Tue Oct 20 2015 i@marguerite.su
- update version 1.4.14
  * Fixed the issues found in static checks
- changes in 1.14.11.1
  * Resolves Bug 1013977 - Slow focus change with ibus-chewing
  * Resolves Bug 1062133 - ibus-chewing may not handle key event
    after focus change
  * Resolves Bug 1073797 - Cannot identify input mode for Chinese
    IME (ibus-chewing)
  * Fixed Bug 902866 - ibus-chewing uses dconf but still installs
    gconf schemas
  * MakerDialog GUI is only loaded when setting dialog is invoked.
  * Setting is removed from ibus-properties because it can be launched
    from either:
    + Executable ibus-setup-chewing: Usually under /usr/libexec
    + Input method preference in IBus preference.
  * Fixed github issue #43: First space not able to input
  * Fixed github issue #44: Update input-events (for libchewing-0.4.0)
  * Fixed github issue #45: Optimize properties handling.
- remove explicit Requires on libchewing > 0.3.2, ldconfig will
  do the work
- drop patch: ibus-chewing-fix-license.patch, upstream fixed
- dont build with gconf support, such codes are buggy
* Wed Aug 13 2014 fcrozat@suse.com
- Add provides locale(zh_TW)
* Wed Jul  2 2014 fcrozat@suse.com
- Add ibus-chewing-fix-license.patch: fix incorrect license on one
  header.
* Sat Mar  1 2014 hillwood@linuxfans.org
- Update to 1.4.10.1
  1.4.7 to 1.4.10.1:
  * Resolves Bug 1054937 - Broken %%defattr in ibus-chewing
  1.4.6 to 1.4.7:
  * Target "translation" is built separately with all, in order to
    tame multiple job make.
  1.4.5 to 1.4.6:
  * Fixed Build for RHEL7
  1.4.4 to 1.4.5:
  * Resolves Bug 1013977 - ibus-chewing needs to have ibus write-cache
  - -system in %%post and %%postun
  * Resolves Bug 1027031 - CVE-2013-4509 ibus-chewing: ibus: visible
    password entry flaw [rhel-7.0]
  * Resolves Bug 1028911 - [zh_TW]'Chinese<->English' switch does not work
    when clicking on the Chewing menu list.
  * Resolves Bug 1045868 - ibus-chewing *again* not built with $RPM_OPT_FLAGS
  * Option "Sync between caps lock and IM":
    + Default of  is changed to "disable",  because the previous default
    "keyboard" cause bug 1028911 for GNOME Shell.
    + Now Sync from "input method" can control Caps LED in GNOME shell.
  * Translation added: de_DE, es_ES, it_IT, pt_BR, uk_UA
  * Set environment IBUS_CHEWING_LOGFILE for ibus-chewing log.
* Thu Dec 19 2013 ftake@geeko.jp
- Update to 1.4.4
  * Fixed IBus issue 1294: Chewing GUI in French [patch]
  * Fixed bogus date
  * Fixed password is visible on GNOME lock screen
    (bnc#847718, CVE-2013-4509)
  * Fixed ibus-chewing 1.4.3-1 not built with (rh#842856)
- Drop cmake-fedora-modules.tar.bz2
  * the source archive includes a newer version of cmake-fedora
* Tue Dec 18 2012 swyear@gmail.com
- Update to 1.4.3
- Fixed GitHub issue #30: Rework decorate_preedit
  by merging pull request #30 from buganini
- Fixed GitHub issue #31: Properly refresh property
  by merging pull request #31 from buganini
* Sat Aug 25 2012 swyear@gmail.com
- Update to 1.4.2
- Fixed GitHub issue #7: highlighted text be cut after switch back to pure ibus
  by merging pull request #24 from buganini
- Fixed GitHub issue #20: Shift key will send duplicated strings
  by merging pull request #22 from buganini
- Fixed GitHub issue #21: somethings wrong with cmake
- Fixed GitHub issue #25: Weird symbol when input with somethings highlighted
  by merging pull request #26 from buganini
- Fixed GitHub issue #27: Local path committed into tree
- Fixed: Bug 713033 -  [zh_TW] ibus-chewing problem
- Fixed: Bug 745371 -  ibus-chewing: mode confusion In Temporary English mode and Chinese mode later on
- Fixed: Google Issue 1172: [ibus-chewing] move elf file to standard directory.
- Fixed: Google Issue 1426: ibus-chewing-1.3.10 installs directory /gconf to root filesystem
- Fixed: Google Issue 1428: ibus-chewing-1.3.10 fails to save it's settings
- Fixed: Google Issue 1481: Some characters are missing when a long string in preedit buffer.
- Fixed: Google Issue 1490: Cannot change INSTAL prefix for ibus-chewing-1.4.0
* Thu Aug 23 2012 swyear@gmail.com
- Update to 1.4.0
- fix issue http://code.google.com/p/ibus/issues/detail?id=1481
* Sun Jun 24 2012 swyear@gmail.com
- Add patch from http://code.google.com/p/ibus/issues/detail?id=1428
  Fix ibus-chewing module's setting can not be saved
* Fri Jun  8 2012 swyear@gmail.com
- remove "Provides: locale(ibus:zh_TW;zh_HK)"
* Tue Mar 20 2012 swyear@gmail.com
- Fix ibus-chewing build fail for ibus-1.4.1
  https://bugs.gentoo.org/show_bug.cgi?id=407695
* Mon Oct 17 2011 swyear@gmail.com
- Update to 1.3.10
- Need cmake-fedora-modules (stated in CMakeList.txt),add to source
- upstream changelog:
- Fixed Bug 726335 (Google issue 1281)- [abrt] ibus-chewing-1.3.9.2-3.fc15: g_atomic_int_get:
  Process /usr/libexec/ibus-engine-chewing was killed by signal 11 (SIGSEGV) using patch from Scott Tsai
- Fixed Bug 727018 - ibus compose file needs a symbol tag for gnome-shell
- Fixed characters duplication problem (Google issue 1245, GitHub ibus-chewing issue 2)
- Fixed KP-Enter not been able to commit preedit buffer. (Google issue 1303, GitHub ibus-chewing issue 4)
- Depends on cmake-fedora now.
- Fixed issue 1274, which is addressed by yusake's comments on d9009bf.
- Add compile flag for GNOME3.
- Add command line option: showFlags
- ibus-gnome special symbol
- Thanks Fred Chien's patch against that candidate window cannot be closed
  with escape key since selected tone.
- Thanks Fourdollar's patch for Fix plain zhuyin with space as selection problem.
- Remove support for ibus-1.2 and prior.
* Mon Jul 25 2011 tiwai@suse.de
- Fix builds with older distros
- Minor spec file cleanup
* Mon Jul 25 2011 tiwai@suse.de
- Don't remove buildroot in install, use make_install macro
* Fri Jul 22 2011 tiwai@suse.de
- Add locale-specific provides tag (bnc#707712)
* Tue Jun 14 2011 swyear@gmail.com
- Update to 1.3.9.2
* Fri Apr 23 2010 tiwai@suse.de
- fix filelist
* Thu Jan 28 2010 mxwu@novell.com
- Initial import
